Reading sensors

Dependencies:   mbed m3pi

Fork of 3pi_Lab1_Task2 by Craig Evans

Revision:
4:3edc12f142f3
Parent:
3:57544dc71dfc
Child:
5:c792f0f3b46d
--- a/main.cpp	Thu Jun 29 09:45:46 2017 +0000
+++ b/main.cpp	Wed Jul 05 10:06:07 2017 +0000
@@ -36,7 +36,7 @@
     // an array to store each of the sensor values
     unsigned int values[5]= {0};
     
-    float dt = 1.0/100.0;  // we'll read the sensors 100 times a second
+    float dt = 1.0/10.0;  // we'll read the sensors 10 times a second
 
     // main loop - this runs forever
     while(1) {